==> cybop-0.17.0.tar.gz: cybop-0.17.0/src/constant/name/command_option/unix/remove_file_unix_command_option_name.c <==
/*
 * Copyright (C) 1999-2015. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.17.0 2015-04-20
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_CONSTANT_SOURCE
#define REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The force remove file unix command option name. */
static wchar_t* FORCE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-f";
static int* FORCE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The interactvie remove file unix command option name. */
static wchar_t* INTERACTIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-i";
static int* INTERACTIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The recursvie remove file unix command option name. */
static wchar_t* RECURSIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-r";
static int* RECURSIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The verbal remove file unix command option name. */
static wchar_t* VERBAL_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-v";
static int* VERBAL_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_CONSTANT_SOURCE */
#endif

==> cybop-0.18.0.tar.gz: cybop-0.18.0/src/constant/name/command_option/unix/remove_file_unix_command_option_name.c <==
/*
 * Copyright (C) 1999-2016. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.18.0 2016-12-21
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_CONSTANT_SOURCE
#define REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The force remove file unix command option name. */
static wchar_t* FORCE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-f";
static int* FORCE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The interactive remove file unix command option name. */
static wchar_t* INTERACTIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-i";
static int* INTERACTIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The recursive remove file unix command option name. */
static wchar_t* RECURSIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-r";
static int* RECURSIVE_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The verbal remove file unix command option name. */
static wchar_t* VERBAL_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME = L"-v";
static int* VERBAL_REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* REMOVE_FILE_UNIX_COMMAND_OPTION_NAME_CONSTANT_SOURCE */
#endif
